@@ -336,7 +336,7 @@ void linebreak_add_prep(linebreak_t * lbobj,
 			linebreak_prep_func_t prep_func, void *prep_data)
 {
     size_t i;
-    linebreak_prep_func_t * p;
+    linebreak_prep_func_t *p;
     void **q;
 
     if (prep_func == NULL) {
@@ -359,7 +359,8 @@ void linebreak_add_prep(linebreak_t * lbobj,
 	for (i = 0; lbobj->prep_func[i] != NULL; i++);
 
     if ((p =
-	 realloc(lbobj->prep_func, sizeof(linebreak_prep_func_t) * (i + 2)))
+	 realloc(lbobj->prep_func,
+		 sizeof(linebreak_prep_func_t) * (i + 2)))
 	== NULL) {
 	lbobj->errnum = errno;
 	return;
@@ -496,6 +497,7 @@ void linebreak_reset(linebreak_t * lbobj)
  *
  * @note This method was introduced by Sombok 2.0.6. 
  * @note LEGACY_CM and HANGUL_AS_AL options are concerned as of Sombok 2.1.2.
+ * @note Only HANGUL_AS_AL is concerned as of Sombok 2.2.
  *
  */
 propval_t linebreak_get_lbrule(linebreak_t * obj, propval_t blbc,
@@ -510,13 +512,6 @@ propval_t linebreak_get_lbrule(linebreak_t * obj, propval_t blbc,
 	blbc = (obj->options & LINEBREAK_OPTION_NONSTARTER_LOOSE) ?
 	    LB_ID : LB_NS;
 	break;
-    /* Legacy-CM */
-    /* This rule follows SP* ÷ SP × CM, not SP × SP+ ÷ CM.
-     * But for simplicity treat it as indirect break. */
-    case LB_SP:
-	if (albc == LB_CM && obj->options & LINEBREAK_OPTION_LEGACY_CM)
-	    return LINEBREAK_ACTION_INDIRECT;
-	break;
     /* Optionally, treat hangul syllable as if it were AL. */
     case LB_H2:
     case LB_H3:
@@ -545,6 +540,7 @@ propval_t linebreak_get_lbrule(linebreak_t * obj, propval_t blbc,
 }
 
 /** Get Line Breaking Class
+ * @deprecated Use gcstring_lbclass() or gcstring_lbclass_ext() instead.
  *
  * Get UAX #14 line breaking class of Unicode character.
  * Classes XX and SG will be resolved to AL.
@@ -557,7 +553,13 @@ propval_t linebreak_lbclass(linebreak_t * obj, unichar_t c)
     propval_t lbc, gcb, scr;
 
     linebreak_charprop(obj, c, &lbc, NULL, &gcb, &scr);
-    if (lbc == LB_SA) {
+    if (lbc == LB_AI)
+	lbc = (obj->options & LINEBREAK_OPTION_EASTASIAN_CONTEXT) ?
+	    LB_ID : LB_AL;
+    else if (lbc == LB_CJ)
+	lbc = (obj->options & LINEBREAK_OPTION_NONSTARTER_LOOSE) ?
+	    LB_ID : LB_NS;
+    else if (lbc == LB_SA) {
 #ifdef USE_LIBTHAI
 	if (scr != SC_Thai)
 #endif				/* USE_LIBTHAI */
@@ -568,6 +570,7 @@ propval_t linebreak_lbclass(linebreak_t * obj, unichar_t c)
 }
 
 /** Get East_Asian_Width Property
+ * @deprecated Use gcstring_columns() instead.
  *
  * Get UAX #11 East_Asian_Width property value of Unicode character.
  * Class A will be resolved to appropriate property F or N.
@@ -580,5 +583,9 @@ propval_t linebreak_eawidth(linebreak_t * obj, unichar_t c)
     propval_t eaw;
 
     linebreak_charprop(obj, c, NULL, &eaw, NULL, NULL);
+    if (eaw == EA_A)
+	eaw = (obj->options & LINEBREAK_OPTION_EASTASIAN_CONTEXT) ?
+	    EA_F : EA_N;
+
     return eaw;
 }
